@@ -33,11 +33,11 @@ class modbus_comm:
 
     async def scan_devices(self):
         """Scan and return a list of eligible BLE devices"""
-        print("Scanning BLE devices (for 5 seconds)...")
+        print("Scanning BLE devices (for 10 seconds)...")
         # device storage array
         self.valid_devices = []  
         try:
-            devices = await BleakScanner.discover(timeout=5)
+            devices = await BleakScanner.discover(timeout=10)
             
             for d in devices:
                 if d.name and (d.name.startswith('RNG') or d.name.startswith('BT')):
@@ -240,6 +240,7 @@ class EnhancedModbusClient(modbus_comm):
         try:
             res = await self.safe_send(self.read_holding_registers,start_address=pdu,
                             register_count=count)
+            print(f"DeviceType:{res.hex()}")
             if res.hex() == '0000' or res.hex() == '0001':
                 return True
         except Exception:
@@ -252,9 +253,11 @@ class EnhancedModbusClient(modbus_comm):
         try:
             res = await self.safe_send(self.read_holding_registers,start_address=pdu,
                                 register_count=count)
-
-            if len(res.hex())> 0:
+            print(f"Battery_name:{res.hex()}")
+            if '4254' in res.hex():
                 return True
+            else:
+                return False
         except Exception:
                 return False
     # Get open data
